# SearchSource: OpenCitations forward search

Note: This document is currently under development. It will contain the following elements.

- description
- coverage (disciplines, types of work)
- supported (details): run_search (including updates), load,  prep (including get_masterdata)

[OpenCitations](https://opencitations.net/)

## Add the search source

```
colrev search -a colrev.open_citations_forward_search:default
```

## Links
